//
//  SIDDevice.h
//  SocialID
//
//  Created by Renato Neves on 2/4/14.
//  Copyright (c) 2014 Coffee Bean Tech. All rights reserved.
//

#import "SIDObject.h"

@interface SIDDevice : SIDObject

@property NSString *deviceToken;
@property NSString *deviceId;

/**
 Creates and returns a device with current configuration.
 */
+ (instancetype)device;

/**
 Sets the deviceToken property.
 Saves it the the user defaults.
 @param deviceToken The device token string.
 */
- (void) setDeviceToken:(NSString *)deviceToken;

/**
 Gets the deviceToken property.
 */
- (NSString *) deviceToken;

/**
 Sets the deviceId property.
 Saves it the the user defaults.
 @param newId The device id string.
 */
- (void) setDeviceId:(NSString *)newId;

/**
 Gets the deviceId property.
 */
- (NSString *) deviceId;

/**
 Sets the device token given the device token object provided by
 didRegisterForRemoteNotificationsWithDeviceToken.
 @param deviceToken The device token NSData.
 */
- (void) setDeviceFromData:(NSData *)deviceToken;

/**
 Link the current device id to the given login user id.
 @param callback A block object to be executed when the request operation finished.
 */
- (void) linkDeviceToUser:(SIDCallbackBlock)callback;

/**
 Saves the device token to Social-ID backend immediately,
 independently if there is network connection or not.
 It doesn't try to create the device if deviceId is already available
 in the user defaults.
 @param callback A block object to be executed when the request operation finished.
 */
- (void) saveWithCallback:(SIDCallbackBlock)callback;

/**
 Creates the device on SocialID backend given its token.
 Sets the deviceID property if created successfully.
 @param deviceToken The device token string.
 @param callback A block object to be executed when the request operation finished.
 */
- (void) create:(NSString *)deviceToken
       callback:(SIDCallbackBlock)callback;

@end
