//
//  SIDFacebook.h
//  SocialID
//
//  Created by Renato Neves on 4/16/14.
//  Copyright (c) 2014 Coffee Bean Tech. All rights reserved.
//

#import <GooglePlus/GooglePlus.h>
#import "SIDProvider.h"

@interface SIDGoogle : NSObject <SIDProvider>

@property NSString *fields;
@property (copy, nonatomic) void (^success)(SIDUser *user);
@property (copy, nonatomic) void (^failure)(NSError *error);

/**
 Get singleton instance.
 */
+ (instancetype) sharedInstance;

/**
 Initializes the Google SDK and registers the provider in the SIDLogin.
 */
+ (void) initializeGoogle;

/**
 Performs the Social Login using the native Google login flow, returning the generated SIDUser or error.
 @param fields The user fields to be retrieved.
 @param success The callback in case of success. A SIDUser object is provided including the specified fields.
 @param failure The callback in case of failure. A NSError object is provided.
 */
- (void) logInWithFields:(NSString *)fields
                 success:(void (^)(SIDUser *user))success
                 failure:(void (^)(NSError *error))failure;

/**
 Logout the user from Google SDK.
 */
- (void) logOut;

/**
 Create a SIDToken object given a Facebook access token.
 @param accessToken A Google+ access token.
 @param success The callback in case of success. A SIDToken object is provided.
 @param failure The callback in case of failure. A NSError object is provided.
 */
- (void) createTokenFromAccessToken:(NSString *)accessToken
                            success:(void (^)(SIDToken *token))success
                            failure:(void (^)(NSError *error))failure;

/**
 Google delegate method
 */
- (void) finishedWithAuth: (GTMOAuth2Authentication *)auth
                    error: (NSError *) error;

/**
 Google delegate method
 */
- (BOOL) application:(UIApplication *)application
             openURL:(NSURL *)url
   sourceApplication:(NSString *)sourceApplication
          annotation: (id)annotation;

/**
 Set the object that implement GPPSignInDelegate protocol
 */
- (void) setDelegate: (id)delegate;

@end
