//
//  SIDLogin.h
//  SocialID
//
//  Created by Renato Neves on 9/16/15.
//  Copyright (c) 2015 Coffee Bean Tech. All rights reserved.
//

#import <UIKit/UIKit.h>

#import "SIDUser.h"
#import "SIDProvider.h"

@interface SIDLogin : NSObject

@property NSString *userFields;
@property NSMutableDictionary *loginProviders;

/**
 Returns the singleton object.
 */
+ (instancetype) sharedInstance;

/**
 Sets the default user profile fields to be retrieved.
 @param fields The user profile fields.
 */
+ (void) setUserFields:(NSString *)fields;

/**
 Registers a login provider.
 @param provider Can be any of "facebook", "google", "linkedin" or "twitter".
 @param manager The provider shared instance.
 */
+ (void) registerLoginProvider:(NSString *)provider
                       manager:(NSObject<SIDProvider> *)manager;

/**
 Starts the given login provider flow.
 @param provider The provider name.
 @param success The success callback, with the SIDUser object.
 @param failure The failure callback, with the NSError object.
 */
+ (void) startLoginProvider:(NSString *)provider
                    success:(void (^)(SIDUser *user))success
                    failure:(void (^)(NSError *error))failure;

/**
 Handles the application:didFinishLaunchingWithOptions: AppDelegate method.
 @param application
 @param launchOptions
 */
+ (void) application:(UIApplication *)application didFinishLaunchingWithOptions:(NSDictionary *)launchOptions;

/**
 Handles the application:openURL:sourceApplication:annotation AppDelegate method.
 @param application
 @param url
 @param sourceApplication
 @param annotation
 */
+ (BOOL) application:(UIApplication *)application
             openURL:(NSURL *)url
   sourceApplication:(NSString *)sourceApplication
          annotation:(id)annotation;

/**
 Logs the user out from socialid session and providers.
 */
+ (void) logOut;

@end
