//
//  SIDProvider.h
//  SocialID
//
//  Created by Renato Neves on 9/16/15.
//  Copyright (c) 2015 Coffee Bean Tech. All rights reserved.
//

#import <UIKit/UIKit.h>

#import "SIDUser.h"
#import "SIDToken.h"

@protocol SIDProvider

/**
 Returns the singleton object.
 */
@required
+ (instancetype) sharedInstance;

/**
 Performs the Social Login flow, returning the generated SIDUser or error.
 @param fields The user fields to be retrieved.
 @param success The callback in case of success. A SIDUser object is provided including the specified fields.
 @param failure The callback in case of failure. A NSError object is provided.
 */
@required
- (void) logInWithFields:(NSString *)fields
                 success:(void (^)(SIDUser *user))success
                 failure:(void (^)(NSError *error))failure;

/**
 Logout the user from provider.
 */
@required
- (void) logOut;

/**
 Handles the application:didFinishLaunchingWithOptions: AppDelegate method.
 @param application
 @param launchOptions
 */
@optional
- (void) application:(UIApplication *)application
didFinishLaunchingWithOptions:(NSDictionary *)launchOptions;

/**
 Handles the application:openURL:sourceApplication:annotation AppDelegate method.
 @param application
 @param url
 @param sourceApplication
 @param annotation
 */
@optional
- (BOOL) application:(UIApplication *)application
             openURL:(NSURL *)url
   sourceApplication:(NSString *)sourceApplication
          annotation:(id)annotation;

@end