//
//  SIDTwitter.h
//  SocialID
//
//  Created by Renato Neves on 10/15/15.
//  Copyright © 2015 Coffee Bean Tech. All rights reserved.
//

#import "SIDProvider.h"

@interface SIDTwitter : NSObject <SIDProvider>

/**
 Returns the singleton object.
 */
+ (instancetype) sharedInstance;

/**
 Initializes the Twitter SDK and registers the provider in the SIDLogin.
 */
+ (void) initializeTwitter;

/**
 Performs the Social Login using the native Facebook login flow, returning the generated SIDUser or error.
 @param fields The user fields to be retrieved.
 @param success The callback in case of success. A SIDUser object is provided including the specified fields.
 @param failure The callback in case of failure. A NSError object is provided.
 */
- (void) logInWithFields:(NSString *)fields
                 success:(void (^)(SIDUser *user))success
                 failure:(void (^)(NSError *error))failure;

/**
 Create a SIDToken object given a Twitter access token and secret.
 @param accessToken A Twitter access token.
 @param accessToken A Twitter access secret.
 @param success The callback in case of success. A SIDToken object is provided.
 @param failure The callback in case of failure. A NSError object is provided.
 */
- (void) createTokenFromAccessToken:(NSString *)accessToken
                       accessSecret:(NSString *)accessSecret
                            success:(void (^)(SIDToken *token))success
                            failure:(void (^)(NSError *error))failure;

/**
 Logs the user out.
 */
- (void) logOut;

@end
